RtpSession class
Native RTP audio handler without WebRTC. Handles plain RTP/AVP audio for Asterisk compatibility.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
no setter
- localPort → int?
-
no setter
- onAudioReceived ↔ dynamic Function(Uint8List audioData)?
-
getter/setter pair
- onError ↔ dynamic Function(String error)?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
initialize(
{String? localIp}) → Future< void> - Initialize RTP socket.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendAudio(
Uint8List audioData, int payloadType) → void -
setRemoteEndpoint(
String host, int port) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → RtpSession
-
final